import logging
import importlib
from pathlib import Path
import os

from fastapi import FastAPI
from pydantic_yaml import parse_yaml_file_as

from devcached.config import DevcachedConfig


# Load the config and setup logging
config_path = Path(os.environ.get("DEVCACHED_CONFIG", "/etc/devcached/config.yaml"))
with config_path.open("r", encoding="utf8") as f:
    config = parse_yaml_file_as(DevcachedConfig, f)
logging.basicConfig(level=logging.DEBUG if config.logging == "debug" else logging.INFO)
logger = logging.getLogger("root")

# If configured, setup Sentry
if config.sentry:
    logger.info("Setting up Sentry")
    import sentry_sdk

    sentry_sdk.init(
        config.sentry.dsn,
        send_default_pii=True,
        max_request_body_size="always",
        traces_sample_rate=0,
    )

# Load modules
api = FastAPI()
for module_name in config.modules.keys():
    logger.info("Loading module %s", module_name)
    module = importlib.import_module(module_name)
    creator = getattr(module, "create_module")
    api.include_router(creator(config))
